<?php

namespace App\Http\Controllers\Admin;

use App\Http\Controllers\Controller;
use Illuminate\Http\Request;

use App\Models\Progression;
use App\Models\MenuAccess;

class Progressions extends Controller
{
    public function add()
    {
        try {
            return view('progression.add');
        } catch (\Exception $e) {
            Log::error('Failed to fetch Progresstions: '.$e->getMessage());
            return back()->with(['message' => 'Failed to load Progresstions.', 'alert-type' => 'error']);
        }
    }
    
    public function save(Request $request)
    {
        $validated = $request->validate([
                        'student_id' => 'nullable|numeric|exists:students,student_id',
                        'student' => 'required',
                        'course' => 'required',
                        'adno' => 'nullable',
                        'passout' => 'nullable|numeric',
                        'cstatus' => 'required',
                        'contact' => 'nullable|numeric',
                        'email' => 'nullable|email',
                        'company' => 'nullable',
                        'location' => 'nullable',
                        'position' => 'nullable',
                        'join_date' => 'nullable|date',
                        'remarks' => 'nullable',
                    ]);
        try {
            
            $validated['date'] = date('Y-m-d');
            $msgArray = []; $exist=0;
            if($validated['student_id']){
                $exist = Progression::where('student_id', $validated['student_id'])->count();
            }
            if($exist == 0){
                $saved = Progression::create($validated);
                if($saved){
                    $msgArray = ['message' => 'Progresstion Saved Successfully.', 'alert-type' => 'success'];
                }else{
                    $msgArray = ['message' => 'Progresstion could not be Saved.', 'alert-type' => 'error'];
                }
            }else{
                $msgArray = ['message' => 'Details Already Exists.', 'alert-type' => 'error'];
            }
                
            return redirect()->route('progression')->with($msgArray);
                
        } catch (\Exception $e) {
            Log::error('Failed to save Progresstion: '.$e->getMessage());
            return back()->with(['message' => 'Failed to save Progresstion.', 'alert-type' => 'error']);
        }
    }
    
    public function report()
    {
        try {
            return view('progression.report');
        } catch (\Exception $e) {
            Log::error('Failed to fetch Progresstions: '.$e->getMessage());
            return back()->with(['message' => 'Failed to load Progresstions.', 'alert-type' => 'error']);
        }
    }
    
    public function getData(Request $request){
            
        $colOrder = [null, 'student', 'adno', 'course', 'passout', 'cstatus', 'company', 'location', 'position', 'contact', 'email', 'remarks', 'date'];
            
        // Get DataTable parameters safely
        $limit = $request->input('length', 10);
        $start = $request->input('start', 0);
        $orderIndex = $request->input('order.0.column', 0);
        $order = $colOrder[$orderIndex] ?? 'date';
        $dir = $request->input('order.0.dir', 'asc');
        
        $status = $request->get('status') ?? null;
        $fdate = $request->get('fdate') ?? null;
        $tdate = $request->get('tdate') ?? null;
            
        // Base query
        $query = Progression::query()
            ->whereNull('deleted_at');
            
        if($status!=null){
            $query->where('cstatus', $status);
        }
        
        if($fdate!=null){
            $query->where('date', '>=', $fdate);
        }
        
        if($tdate!=null){
            $query->where('date', '<=', $tdate);
        }
            
        // Search box filtering
        if ($search = $request->input('search.value')) {
            $query->where(function ($qry) use ($search) {
                $qry->where('student', 'like', "%$search%")
                    ->orWhere('adno', 'like', "%$search%")
                    ->orWhere('course', 'like', "%$search%")
                    ->orWhere('passout', 'like', "%$search%")
                    ->orWhere('cstatus', 'like', "%$search%")
                    ->orWhere('company', 'like', "%$search%")
                    ->orWhere('location', 'like', "%$search%")
                    ->orWhere('position', 'like', "%$search%")
                    ->orWhere('contact', 'like', "%$search%")
                    ->orWhere('email', 'like', "%$search%")
                    ->orWhere('remarks', 'like', "%$search%")
                    ->orWhere('date', 'like', "%$search%");
            });
        }
            
        // Get total filtered count before applying pagination
        $totalFiltered = $query->count();
            
        // Select necessary columns and apply ordering, pagination
        $progressions = $query->orderBy($order, $dir)->offset($start)->limit($limit)->get();
            
        // Permissions
        $delete = MenuAccess::have_access(736);
            
        // Prepare data for response
        $data = [];
        $i=$start;
        foreach ($progressions as $progression) {
            $i++;
            
            $actions = '';
            if ($delete) {
                $actions .= '<a href="'.route('progression.delete', encrypt($progression->id)).'" title="Delete" onclick="return confirm(\'Are you sure you want to delete?\');"><i class="icon-sm icon-trash text-danger"></i></a>';
            }
            
            $row = [
                'sno' => $i,
                'name' => htmlspecialchars(strtoupper($progression->student)),
                'adno' => htmlspecialchars($progression->adno),
                'course' => htmlspecialchars(strtoupper($progression->course)),
                'passout' => htmlspecialchars($progression->passout),
                'status' => htmlspecialchars(strtoupper($progression->cstatus)),
                'company' => htmlspecialchars(strtoupper($progression->company)),
                'location' => htmlspecialchars(strtoupper($progression->location)),
                'position' => htmlspecialchars(strtoupper($progression->position)),
                'contact' => htmlspecialchars($progression->contact),
                'email' => htmlspecialchars($progression->email),
                'remarks' => htmlspecialchars(strtoupper($progression->remarks)),
                'date' => date('d/m/Y', strtotime($progression->date)), 
                'action' => $actions
            ];
            $data[] = $row;
        }
            
        // Return JSON response
        return response()->json([
            'draw' => intval($request->input('draw')),
            'recordsTotal' => Progression::whereNull('deleted_at')->count(),
            'recordsFiltered' => $totalFiltered,
            'data' => $data
        ]);
    }
    
    public function delete($pid)
    {
        try {
            $progression = Progression::find(decrypt($pid));
            if($progression->delete()){
                $msgArray = ['message' => 'Progresstion Deleted Successfully.', 'alert-type' => 'success'];
            }else{
                $msgArray = ['message' => 'Progresstion could not be Deleted.', 'alert-type' => 'error'];
            }
            return redirect()->route('progression')->with($msgArray);
            
        } catch (\Exception $e) {
            Log::error('Failed to fetch Progresstions: '.$e->getMessage());
            return back()->with(['message' => 'Failed to load Progresstions.', 'alert-type' => 'error']);
        }
    }
}
