<?php

namespace App\Http\Controllers\Admin;

use App\Http\Controllers\Controller;
use Illuminate\Http\Request;
use Illuminate\Support\Facades\Auth;
use Illuminate\Support\Facades\Log;

use App\Models\User;
use App\Models\Periods;
use App\Models\Timetable;
use App\Models\StudentAttendance;
use App\Models\Promote;
use App\Models\Course;
use App\Models\Semester;
use App\Models\Subject;
use App\Models\Student;
use App\Models\SubCategory;
use App\Models\AcHoliday;
use App\Models\MenuAccess;
use App\Models\HOD;
use App\Models\FyugpTimetable;
use Maatwebsite\Excel\Facades\Excel;
use App\Exports\AttendanceConsolidateExport;

use DB;
use Carbon\Carbon;

class StudentAttendances extends Controller
{
    public function report(Request $request){
        
        try {
     /*$sb= Subject::getStaffSubjects(6); echo "<pre>"; print_r($sb); */
            $acyearId = getAcyear();
            $user = Auth::user(); 
            $userId = $user->user_id; 
            
            $courses = Course::getStaffCourses();
            $courseId = $request->input('course') ?? null;
            $semesterId = $request->input('semester') ?? null;
            $subjectId = $request->input('subject') ?? null;
            $batchId = $request->input('batch_id') ?? null;
            $month = $request->input('month') ?? date('Y-m');
            $semesters = $batchs = $subjects = $students = $msgArray = $weeks = [];
            
            if($courseId!=null) {
                $semesters = Semester::getStaffSemesters($courseId);
            }
            if($semesterId!=null) {
                $subjects = Subject::getStaffSubjects($semesterId);
            }
           
            if($batchId!=null) {
                 $batchs = FyugpTimetable::join('groups', 'fyugp_timetable.group_id', '=', 'groups.id')
                ->where('fyugp_timetable.acyear', $acyearId)
                ->where('fyugp_timetable.user_id', $userId)
                ->where('fyugp_timetable.subject_id', $subjectId)
                ->where('groups.department_id', $user->dept_id)
                ->distinct()
                ->select('groups.name', 'groups.id')
                ->get();    
               
            }
            
            $acyearId = getAcyear();
            if($courseId!=null && $semesterId!=null && $subjectId!=null && $month!=null) {
                $weeks = getWeeksOfMonth(date('Y',strtotime($month)), date('m',strtotime($month)));
            } else {
                $msgArray = ['message'=>'Please select all fields !','alert-type'=>'error'];
            }
          
            return view('student-attendance.report', compact('courses', 'courseId', 'semesters', 'semesterId', 'subjects', 'subjectId','batchs','batchId','month', 'weeks'))->with($msgArray);
      } catch (\Exception $e) {
            Log::error('Failed to fetch Attendance: '.$e->getMessage());
            return back()->withErrors('Failed to load Attendance.');
        }
    }
    
    public function weekReport(Request $request){ 
      try{
            $courseId = $request->input('course') ?? null; 
            $semesterId = $request->input('semester') ?? null;
            $subjectId = $request->input('subject') ?? null;
            $batchId = $request->input('batch_id') ?? null;
            $sDate = $request->input('sdate') ?? null; 
           $eDate = $request->input('edate') ?? null;
            $acyearId = getAcyear();
          
            if($courseId!=null && $semesterId!=null && $subjectId!=null && $sDate!=null && $eDate!=null) {    
                $subject = Subject::find($subjectId); 
                $semester = Semester::find($semesterId);
                $semesterIds = Semester::where('semester_name', $semester->semester_name)->pluck('semester_id')->toArray();
               
                $query = Promote::join('students', 'promotes.student_id', '=', 'students.student_id')
                    ->join('courses', 'promotes.course_id', '=', 'courses.course_id');
                if(in_array($subject->subject_categ, [2,3,4,5,6])) {
                    if ($batchId != null && $batchId != '') { 
                    $courses = DB::table('group_courses')->where('group_id',$batchId)->pluck('course_id')->toArray();
                    $query->whereIn('promotes.course_id', $courses); 
                }
                    $query->join('fyugp_stud_sub', 'promotes.student_id', '=', 'fyugp_stud_sub.stud_id')
                        ->where('fyugp_stud_sub.acyear_id', $acyearId)
                        ->where('fyugp_stud_sub.sub_id', $subjectId)
                        ->whereIn('promotes.semester_id', $semesterIds)
                        ->whereIn('fyugp_stud_sub.sem', $semesterIds);
                       
                } else {
                    $query->where('promotes.course_id', $courseId)
                        ->where('promotes.semester_id', $semesterId);
                } 
                $students = $query->where('promotes.ac_id', $acyearId)
                    ->select('students.student_id','students.adno','students.name','students.rollno','students.clno','courses.course_name')
                    ->groupBy('promotes.student_id')
                    ->orderBy('students.clno', 'ASC')
                    ->get();
              
                $attendances = StudentAttendance::whereBetween('date', [$sDate, $eDate])
                    ->where('subject_id', $subjectId)
                    ->orderBy('period_id')
                    ->get();
                
                $data = [];
                foreach($attendances as $attendance){
                    $color = "";
                    if($attendance->status=='P'){
                        $color = "#38ce3c";
                    }else if($attendance->status=='A'){
                        $color = "#ff4d6b";
                        if($attendance->leave_id != null){
                            $color = $attendance->leavetype->leave_color;
                        }
                    }
                    
                    $data[$attendance->student_id][$attendance->date][$attendance->period_id] = [
                            'period' => $attendance->period->period,
                            'status' => $attendance->status,
                            'reason' => $attendance->reason,
                            'color' => $color
                        ];
                }
                
                $results = AcHoliday::whereDate('start_date', '<=', $eDate)
                                ->whereDate('end_date', '>=', $sDate)
                                ->where('student', 1)
                                ->get();
                $holidays = [];
                foreach($results as $result){
                    if($result->start_date==$result->end_date){
                        $holidays[] = $result->start_date;
                    }else{
                        $hsDate = Carbon::parse($result->start_date);
                        $heDate = Carbon::parse($result->end_date);
                        while ($hsDate->lte($heDate)){
                            $hcDate = $hsDate->toDateString();
                            if(!in_array($hcDate, $holidays)){
                                $holidays[] = $hcDate;
                            }
                            $hsDate = $hsDate->addDay();
                        }
                    }
                }
               
                $startDate = Carbon::parse($sDate);
                $endDate = Carbon::parse($eDate);
                $dates = [];
                while ($startDate->lte($endDate)){
                    $dates[] = $startDate->toDateString();
                    $startDate = $startDate->addDay();
                }
               
                return view('student-attendance.week', compact('students', 'dates', 'attendances', 'data', 'holidays'));
                
            }
       } catch (\Exception $e) {
            Log::error('Failed to fetch Attendance: '.$e->getMessage());
            return back()->withErrors('Failed to load Attendance.');
        }
    }
    
    public function consolidate(Request $request){
        try{
            $user = Auth::user();
            $courses = Course::getStaffCourses();
            
            $courseId = $request->input('course') ?? null;
            $semesterId = $request->input('semester') ?? null;
            $month = $request->input('month') ?? date('Y-m');
            $semesters = $students = $subjects = $data = $msgArray = [];
            if($courseId!=null){
                $semesters = Semester::getStaffSemesters($courseId);
            }
            $acyearId = getAcyear();
            $export = MenuAccess::have_access(741) ? 1:0;
            if($courseId!=null && $semesterId!=null && $month!=null){
                $startDate = Carbon::createFromFormat('Y-m', $month)->startOfMonth()->toDateString();
                $endDate = Carbon::createFromFormat('Y-m', $month)->endOfMonth()->toDateString();
                $marked = StudentAttendance::whereBetween('date', [$startDate, $endDate])->where('course_id', $courseId)->where('semester_id', $semesterId)->select('subject_id', DB::raw('COUNT(DISTINCT CONCAT(date, "-", period_id)) as hours'))->groupBy('subject_id')->get();
                
                $semester = Semester::find($semesterId);
                $subcategories = SubCategory::all();
                foreach ($subcategories as $subcategory) {
                    $query = Subject::query();
                    if (in_array($subcategory->id, [2, 3, 4, 5, 6])) {
                        $query->join('fyugp_stud_sub', 'subjects.subject_id', '=', 'fyugp_stud_sub.sub_id')
                            ->where('fyugp_stud_sub.course', $courseId)
                            ->where('fyugp_stud_sub.sem', $semesterId)
                            ->where('fyugp_stud_sub.acyear_id', $acyearId);
                    } else {
                        $query->join('course_subject', 'subjects.subject_id', '=', 'course_subject.subject_id')
                            ->where('course_subject.course_id', $courseId)
                            ->where('course_subject.semester_id', $semester->semester_name);
                    }
                        
                    $results = $query->where('subjects.subject_categ', $subcategory->id)
                        ->select('subjects.subject_id', 'subjects.subject_name')
                        ->groupBy('subjects.subject_id')->get();
                        
                    foreach ($results as $result) {
                        $subjectHours = $marked->where('subject_id', $result->subject_id)->first();
                        $mcount=0;
                        if($subjectHours){
                            $mcount = $subjectHours->hours;
                        }
                        
                        $subjects[] = ['id' => $result->subject_id, 'name' => $result->subject_name, 'hours' => $mcount];
                    }
                }
                
                $students = Promote::join('students', 'promotes.student_id', '=', 'students.student_id')
                    ->where('promotes.course_id', $courseId)
                    ->where('promotes.semester_id', $semesterId)
                    ->where('promotes.ac_id', $acyearId)
                    ->select('students.student_id','students.adno','students.clno','students.rollno','students.name')
                    ->groupBy('promotes.student_id')
                    ->orderBy('students.clno', 'ASC')
                    ->get();
                    
                $attendanceData = StudentAttendance::whereBetween('date', [$startDate, $endDate])
                    ->where('course_id', $courseId)
                    ->where('semester_id', $semesterId)
                   
                    ->select(
                        'student_id',
                        'subject_id',
                        DB::raw('COUNT(DISTINCT CONCAT(date, "-", period_id)) as total_hours'),
                        DB::raw("SUM(CASE WHEN status='P' THEN 1 ELSE 0 END)AS present")
                    )
                    ->groupBy('student_id', 'subject_id')
                    ->get()
                    ->groupBy(['student_id', 'subject_id']);
                    
                foreach($students as $student){
                    foreach($subjects as $subject){
                        $pcount=$percent=0;
                        $attendance = $attendanceData[$student->student_id][$subject['id']] ?? collect();
                            
                        if ($attendance->isNotEmpty()) {
                            $pcount = $attendance->first()->present;

                            if ($subject['hours'] > 0) {
                                $percent = round(($pcount/$subject['hours']) * 100);
                            }
                                
                            $data[$student->student_id][$subject['id']] = ['present' => $pcount, 'percent' => $percent];
                        }
                    }
                }
                
            }else{
                $msgArray = ['message'=>'Please select all fields !','alert-type'=>'error'];
            }
            
            return view('student-attendance.consolidate', compact('courses', 'courseId', 'semesters', 'semesterId', 'month', 'students', 'subjects', 'data', 'export'))->with($msgArray);
        } catch (\Exception $e) {
            Log::error('Failed to fetch Attendance: '.$e->getMessage());
            return back()->withErrors('Failed to load Attendance.');
        }
    }
    
    public function export_consolidate(Request $request){
        try{
            $courseId = $request->get('course') ?? null;
            $semesterId = $request->get('semester') ?? null;
            $month = $request->get('month') ?? date('Y-m');
            
            if (!$courseId || !$semesterId || !$month) {
                return back()->withErrors('Missing required parameters!');
            }
                
            $startDate = Carbon::createFromFormat('Y-m', $month)->startOfMonth()->toDateString();
            $endDate = Carbon::createFromFormat('Y-m', $month)->endOfMonth()->toDateString();
            $acyearId = getAcyear();
            
            $marked = StudentAttendance::whereBetween('date', [$startDate, $endDate])->where('course_id', $courseId)->where('semester_id', $semesterId)->select('subject_id', DB::raw('COUNT(DISTINCT CONCAT(date, "-", period_id)) as hours'))->groupBy('subject_id')->get();
            $semester = Semester::find($semesterId);
            $subcategories = SubCategory::all();
            foreach ($subcategories as $subcategory) {
                $query = Subject::query();
                if (in_array($subcategory->id, [2, 3, 4 , 5, 6])) {
                    $query->join('fyugp_stud_sub', 'subjects.subject_id', '=', 'fyugp_stud_sub.sub_id')
                        ->where('fyugp_stud_sub.course', $courseId)
                        ->where('fyugp_stud_sub.sem', $semesterId)
                        ->where('fyugp_stud_sub.acyear_id', $acyearId);
                } else {
                    $query->join('course_subject', 'subjects.subject_id', '=', 'course_subject.subject_id')
                        ->where('course_subject.course_id', $courseId)
                        ->where('course_subject.semester_id', $semester->semester_name);
                }
                
                $results = $query->where('subjects.subject_categ', $subcategory->id)
                    ->select('subjects.subject_id', 'subjects.subject_name')
                    ->groupBy('subjects.subject_id')->get();
                    
                foreach ($results as $result) {
                    $subjectHours = $marked->where('subject_id', $result->subject_id)->first();
                    $mcount=0;
                    if($subjectHours){
                        $mcount = $subjectHours->hours;
                    }
                    
                    $subjects[] = ['id' => $result->subject_id, 'name' => $result->subject_name, 'hours' => $mcount];
                }
            }
            
            $students = Promote::join('students', 'promotes.student_id', '=', 'students.student_id')
                ->where('promotes.course_id', $courseId)
                ->where('promotes.semester_id', $semesterId)
                ->where('promotes.ac_id', $acyearId)
                ->select('students.student_id', 'students.adno', 'students.name')
                ->groupBy('promotes.student_id')
                ->orderBy('students.name', 'ASC')
                ->get();
            
            $attendanceData = StudentAttendance::whereBetween('date', [$startDate, $endDate])
                ->where('course_id', $courseId)
                ->where('semester_id', $semesterId)
                
                ->select(
                    'student_id',
                    'subject_id',
                    DB::raw('COUNT(DISTINCT CONCAT(date, "-", period_id)) as total_hours'),
                    DB::raw("SUM(CASE WHEN status='P' THEN 1 ELSE 0 END)AS present")
                )
                ->groupBy('student_id', 'subject_id')
                ->get()
                ->groupBy(['student_id', 'subject_id']);
                
            $data = [];
            foreach($students as $student){
                foreach($subjects as $subject){
                    $pcount=$percent=0;
                    $attendance = $attendanceData[$student->student_id][$subject['id']] ?? collect();
                        
                    if ($attendance->isNotEmpty()) {
                        $pcount = $attendance->first()->present ;
                    
                        
                    if ($subject['hours'] > 0) {
                        $percent = round(($pcount/$subject['hours']) * 100);
                    }
                        
                    $data[$student->student_id][$subject['id']] = ['present' => $pcount, 'percent' => $percent];
                    }  
                }
            }
                
            // Pass data to export class
          //  $exportData = compact('students', 'subjects', 'data');
            
            return Excel::download(new AttendanceConsolidateExport($students, $subjects, $data), 'attendance-consolidate.xlsx');
        } catch (\Exception $e) {
            Log::error('Failed to fetch Attendance: '.$e->getMessage());
            return back()->withErrors('Failed to load Attendance.');
        }
    }
}
