<?php

namespace App\Http\Controllers;

use Illuminate\Support\Facades\DB;
use Illuminate\Http\Request;
use Illuminate\Support\Facades\Auth;
use Illuminate\Support\Facades\Log;

use App\Models\Acyear;
use App\Models\Periods;
use App\Models\Timetable;
use App\Models\StaffSubject;
use App\Models\User;
use App\Models\Department;
use App\Models\Course;
use App\Models\SubjectType; 
use App\Models\Semester;
use App\Models\Subject;
use App\Models\DayOfWeek;
use App\Models\TimetableTemporary;
use App\Models\Promote;
use App\Models\Student;
use App\Models\Studentleavetype;
use App\Models\StudentAttendance;
use App\Models\FyugpTimetable;
use App\Models\SubCategory;
use App\Models\Group;

use Carbon\Carbon;

class FyugpTimetables extends Controller
{
    public function generate(Request $request)
    {
        try {
            $courses = Course::all();
            $courseId = $request->input('course') ?? null;
            $semesterId = $request->input('semester') ?? null;
            $semesters = $data = $msgArray = $days = $periods = $course = $semester = $staffs = [];
            if($courseId!=null){
                $semesters = Semester::where('course_id', $courseId)->get();
            }
            
            $acyearId = getAcyear();
            if($courseId!=null && $semesterId!=null && $acyearId!=null) {
                $days = DayOfWeek::all();
                $periods = Periods::where('acyear', $acyearId)->get();
                $course = Course::find($courseId);
                $staffs = User::where('dept_id', $course->department_id)->get();
                $semester = Semester::find($semesterId);
                $timetable = FyugpTimetable::where('acyear', $acyearId)->where('course', $courseId)->where('semester', $semesterId)->get();
                foreach($days as $day) {
                    foreach($periods as $period) {
                        $timeperiods = $timetable->where('day_of_week', $day->day)->where('period_id', $period->id);
                        if($timeperiods->count() > 0) {
                            foreach($timeperiods as $timeperiod) {
                                $data[$day->day][$period->id][] = [
                                        'data_id' => $timeperiod->id,
                                        'category_id' => $timeperiod->categ_id,
                                        'category_name' => $timeperiod->category->category,
                                        'group_id' => $timeperiod->group_id,
                                        'group_name' => $timeperiod->group ? $timeperiod->group->name:null,
                                        'user_id' => $timeperiod->user_id,
                                        'user_name' => $timeperiod->user->name,
                                        'user_code' => $timeperiod->user->code,
                                        'type' => $timeperiod->type
                                    ];
                            }
                        } else {
                            $data[$day->day][$period->id] = [];
                        }
                    }
                }
            }
            
            return view('fyugp.timetable.generate', compact('courses', 'courseId', 'course', 'semesters', 'semesterId', 'semester', 'days', 'periods', 'staffs', 'data'));
        } catch (\Exception $e) {
            Log::error('Failed to fetch FYUGP Timetable: '.$e->getMessage());
            return back()->withErrors('Failed to load FYUGP Timetable.');
        }
    }
    
    public function add(Request $request)
    {
        $course_id = $request->cid ?? null;
        $semester_id = $request->sid ?? null;
        $day = $request->day ?? null;
        $period_id = $request->pid ?? null;
        
        if($course_id!=null && $semester_id!=null && $day!=null && $period_id!=null) {
            $course = Course::find($course_id);
            $semester = Semester::find($semester_id);
            $period = Periods::find($period_id);
            $categories = SubCategory::where('id', '<=', 8)->get();
            $groups = Group::join('courses', 'groups.department_id', '=', 'courses.department_id')->where('courses.course_id', $course_id)->get();
            $staffs = User::join('courses', 'users.dept_id', '=', 'courses.department_id')->where('courses.course_id', $course_id)->get();
            
            return view('fyugp.timetable.add',compact('course', 'semester', 'period', 'day', 'categories', 'groups', 'staffs'));
        }
        return false;
    }
    
    public function save(Request $request){
        try{
            $course = $request->course ?? null;
            $semester = $request->semester ?? null;
            $day = $request->day ?? null;
            $period = $request->period ?? null;
            $category = $request->category ?? null;
            $type = $request->type ?? null;
            $staff = $request->staff ?? null;
            $group = $request->group ?? null;
            
            $acyearId = getAcyear();
            
            if($course!=null && $semester!=null && $day!=null && $period!=null && $category!=null && $type!=null && $staff!=null && $acyearId!=null) {
                
                FyugpTimetable::create([
                        'day_of_week' => $day,
                        'period_id' => $period,
                        'course' => $course,
                        'semester' => $semester,
                        'categ_id' => $category,
                        'group_id' => $group,
                        'user_id' => $staff,
                        'type' => $type,
                        'acyear' => $acyearId
                    ]);
                        
                $msgArray = ['message'=>'Timetable Added Successfully !','alert-type'=>'success'];
            }else{
                $msgArray = ['message'=>'Timetable could not be Added !','alert-type'=>'error'];
            }
            
            return redirect()->route('generate.fyugptimetable', ['course'=>$course, 'semester'=>$semester])->with($msgArray);
            
        } catch (\Exception $e) {
            Log::error('Failed to fetch Data: ' . $e->getMessage());
            return back()->with(['message'=>'Failed to load Data.','alert-type'=>'error']);
        }
    }
    
    public function edit(Request $request)
    {
        $course_id = $request->cid ?? null;
        $semester_id = $request->sid ?? null;
        $day = $request->day ?? null;
        $period_id = $request->pid ?? null;
        $id = $request->id ?? null;
        
        if($course_id!=null && $semester_id!=null && $day!=null && $period_id!=null && $id!=null) {
            $course = Course::find($course_id);
            $semester = Semester::find($semester_id);
            $period = Periods::find($period_id);
            $timeperiod = FyugpTimetable::find($id);
            $categories = SubCategory::where('id', '<=', 8)->get();
            $groups = Group::join('courses', 'groups.department_id', '=', 'courses.department_id')->where('courses.course_id', $course_id)->get();
            $staffs = User::join('courses', 'users.dept_id', '=', 'courses.department_id')->where('courses.course_id', $course_id)->get();
            $subjects = StaffSubject::where('course_id', $course_id)->where('semester_id', $semester_id)->where('category_id', $timeperiod->categ_id)->where('user_id', $timeperiod->user_id)->where('acyear_id', $timeperiod->acyear)->distinct('subject_id')->get();
            
            return view('fyugp.timetable.edit',compact('course', 'semester', 'period', 'day', 'timeperiod', 'categories', 'groups', 'staffs', 'subjects'));
        }
        return false;
    }
    
    public function update(Request $request){
        try{
            $course = $request->course ?? null;
            $semester = $request->semester ?? null;
            $day = $request->day ?? null;
            $period = $request->period ?? null;
            $category = $request->category ?? null;
            $type = $request->type ?? null;
            $staff = $request->staff ?? null;
            $subject = $request->subject ?? null;
            $group = $request->group ?? null;
            $ids = $request->ids ?? null;
            
            $acyearId = getAcyear();
            
            if($course!=null && $semester!=null && $day!=null && $period!=null && $category!=null && $type!=null && $staff!=null && $acyearId!=null && $ids!=null){
                $fyugp = FyugpTimetable::find($ids);
                $fyugp->update([
                        'categ_id' => $category,
                        'group_id' => $group,
                        'user_id' => $staff,
                        'subject_id' => $subject,
                        'type' => $type,
                    ]);
                        
                $msgArray = ['message'=>'Timetable Added Successfully !','alert-type'=>'success'];
            }else{
                $msgArray = ['message'=>'Timetable could not be Added !','alert-type'=>'error'];
            }
            
            return redirect()->route('generate.fyugptimetable', ['course'=>$course, 'semester'=>$semester])->with($msgArray);
            
        } catch (\Exception $e) {
            Log::error('Failed to fetch Data: ' . $e->getMessage());
            return back()->with(['message'=>'Failed to load Data.','alert-type'=>'error']);
        }
    }
    
    public function generatefyugptimetable_get(Request $request)
    {
        $course_id = $request->get('course_id');
        $semester_id = $request->get('semester_id');
        $ac_id = getAcyear();
        $periods = Periods::where('acyear', $ac_id)->get();
        $getDayOfWeek = DayOfWeek::all();
        $subject_category = SubCategory::all();
        $assigned = true;
    }
    
    public function viewfyugptimetable_get(Request $request)
    {
        $course_id = $request->get('course_id');
        $semester_id = $request->semester_id;
        $ac_id = getAcyear();
        $periods = Periods::where('acyear', $ac_id)->get();
        $subject_category = SubCategory::all();
        $getDayOfWeek = DayOfWeek::all();
        $timetable = FyugpTimetable::where('acyear', $ac_id)->where('semester', $semester_id)->where('course', $course_id)->get();
        
        return view('fyugp.timetable.fgenerateTimetable_get',compact('semester_id','periods','ac_id','timetable','getDayOfWeek','subject_category','course_id'));
    }
    
    public function fyugptimetable_update(Request $request)
    {
        $courseid = $request->courseId;
        $sem = $request->semesterId;
        $period_id = $request->period_id;
        $day_of_week = $request->day_of_week;
        $categ_id = $request->categ_id;
        $subtype = $request->subtype;
        $uptype = $request->uptype;
        $ac_id = getAcyear();
        $is_free_period = $request->is_free_period; 
        if ($is_free_period == 'true') {
            $checkfree = FyugpTimetable::where([
                'course' => $courseid,
                'semester' => $sem,
                'period_id' => $period_id,
                'day_of_week' => $day_of_week,
                'acyear' => $ac_id,
            ])->first();
            if ($checkfree) {
                $checkfree->delete();
            } 
        } else {
            if($uptype == 0) {
                FyugpTimetable::create([
                    'period_id' => $period_id,
                    'day_of_week' => $day_of_week,  
                    'categ_id' => $categ_id,
                    'course' => $courseid, 
                    'semester'=>$sem,
                    'type'=>$subtype,
                    'acyear' => $ac_id
                ]);
            } else {
                $check = FyugpTimetable::where([
                        'course' => $courseid,
                        'semester' => $sem,
                        'period_id' => $period_id,
                        'day_of_week' => $day_of_week,
                        'acyear' => $ac_id,
                    ])->first();
                if ($check) {
                    $check->update([
                        'categ_id' => $categ_id,'type'=>$subtype,
                    ]);
                } else {
                    FyugpTimetable::create([
                        'period_id' => $period_id,
                        'day_of_week' => $day_of_week,  
                        'categ_id' => $categ_id,
                        'course' => $courseid,
                        'semester'=>$sem,
                        'type'=>$subtype,
                        'acyear' => $ac_id
                    ]);
                }
            }
        }
        return true;
    }
    
    public function staff() {
        $userId = Auth::id();
        $acyearId = getAcyear();
        $periods = Periods::where('acyear', $acyearId)->get();
        $days = DayOfWeek::all();
      
        $timetable = FyugpTimetable::join('subjects', 'subjects.subject_categ', '=', 'fyugp_timetable.categ_id')->join('staff_subject', 'subjects.subject_id', '=', 'staff_subject.subject_id')
            ->where('fyugp_timetable.acyear', $acyearId)
            ->where('staff_subject.acyear_id', $acyearId)
            ->where('staff_subject.user_id', $userId)
            ->select('fyugp_timetable.*', 'subjects.subject_name','subjects.subject_name','staff_subject.course_id')
            ->get();
            
        $data = [];
        foreach($days as $day) {
            foreach($periods as $period) {
                $timeperiod = $timetable->where('period_id',$period->id)->where('day_of_week', $day->day)->first();
                if($timeperiod) {
                    $course_name = Course::where('course_id', $timeperiod->course_id)->pluck('course_name')->first(); 
                    $data[$day->day][$period->id] = [
                            'subject' => $timeperiod->subject_name, 
                            'course' => $timeperiod->subjectcateg->category,
                            'semester' => $timeperiod->semester,
                            'type' => $timeperiod->type,
                            'course_name'=>$course_name,
                            'categid'=>$timeperiod->categ_id
                        ];
                }
            }
        }
        
        return view('fyugp.timetable.staff', compact('days', 'periods', 'data'));
    }
    
     public function department(Request $request) {
        $departments = Department::all();
        $acyearId = getAcyear();
        $periods = Periods::where('acyear', $acyearId)->get();
        $days = DayOfWeek::all();
        $departmentId = $request->input('department') ?? null;
        $data = $staffs = []; $depart = null;
        if($departmentId) {
            $depart = Department::findOrFail($departmentId);
            $staffs = User::where('dept_id', $departmentId)->get();
            $timetable = FyugpTimetable::join('users', 'fyugp_timetable.user_id', '=', 'users.user_id')
                ->where('fyugp_timetable.acyear', $acyearId)
                ->where('users.dept_id', $departmentId)
                ->select('fyugp_timetable.*', 'users.code', 'users.name')
                ->get();
            
            foreach($days as $day){
                foreach($periods as $period){
                    $timeperiods = $timetable->where('period_id', $period->id)->where('day_of_week', $day->day);
                    
                    if($timeperiods) {
                        foreach($timeperiods as $timeperiod) { 
                            $subject_query = StaffSubject::where('user_id', $timeperiod->user_id)
                                ->where('course_id', $timeperiod->course)
                                ->where('semester_id', $timeperiod->semester)
                                ->where('category_id', $timeperiod->categ_id);
                            if($timeperiod->subject_id != null && $timeperiod->subject_id > 0) {
                                $subject_query->where('subject_id', $timeperiod->subject_id);
                            }
                            $subject = $subject_query->first();
                            
                            $subject_name='';
                            if($subject) {
                                $subject_name = $subject->subject->subject_name;
                            }
                            
                            $data[$day->day][$period->id][] = [
                                'subject' => $subject_name, 
                                'category' => $timeperiod->category->category,
                                'semester' => $timeperiod->semesterdet->semester_name,
                                'type' => $timeperiod->type,
                                'group' => $timeperiod->group->name,
                                'scode' => $timeperiod->code,
                                'sname' => $timeperiod->name
                            ];
                        }
                    } else {
                        $data[$day->day][$period->id] = [];
                    }
                }
            }
        }
        
        return view('fyugp.timetable.department', compact('departments', 'periods', 'days', 'departmentId', 'depart', 'staffs', 'data'));
    }
    
}