<?php

namespace App\Http\Controllers;

use Illuminate\Http\Request;
use Illuminate\Support\Facades\Cache;
use Illuminate\Support\Facades\Hash;
use Illuminate\Support\Facades\DB;
use Illuminate\Support\Facades\Storage;

use App\Models\Acyear;
use App\Models\User;
use App\Models\iqacmodel;
use App\Models\Iqacdocumentmodel;
use App\Models\Staffiqacdocument;
use App\Models\Iqacdocumentupload;
use App\Models\MenuAccess;

class Iqac extends Controller
{
    public function iqac_upload(){
        $acyears = Acyear::all();
        $criterias = iqacmodel::all();
        $documents = [];
        $ac_id = getAcyear();
        if(old('criteria_id')){
            $documents = Iqacdocumentmodel::where('criteria_id',old('criteria_id'))->get();
        }
            
        return view('iqac.iqacupload',compact('acyears','criterias','documents','ac_id'));
    }
    
    public function save(Request $request){
        $validated = $request->validate([
            'acyear_id' => 'required',
            'criteria_id' => 'required',
            'document_id'=>'required',
            'evidence'=>'required|mimes:doc,docx,pdf,jpeg,jpg,png|max:5120',
        ]);
            
        if($request->hasFile('evidence')){
            $file = $request->evidence;
            $ext = $file->extension();
            $evidence = 'evidence_'.time().'.'.$ext;
            
            $file->storeAs('iqac/documents',$evidence);
        }
            
        $docupload = Iqacdocumentupload::create([     
            'acyear_id' => $request->acyear_id,
            'criteria_id'=>$request->criteria_id,
            'document_id'=>$request->document_id,
            'evidence'=>$evidence,
            'utype'=>auth()->user()->utype->type_id,
            'staff_id'=>auth()->user()->user_id,
        ]); 
        
        if($docupload){
            $msg_array = array('message'=>'Document Uploaded Successfully !','alert-type'=>'success');
        }else{
            $msg_array = array('message'=>'Document Could not be Uploaded !','alert-type'=>'error');
        }
        
        return redirect()->route('iqacupload')->with($msg_array);
    }
    
    public function iqac_report(){
        $acyears = Acyear::all();
        $criterias = iqacmodel::all();
        $ac_id = getAcyear();    
        return view('iqac.report',compact('acyears','criterias','ac_id'));
    }
    
     public function getData(Request $request){
        $col_order = ['document','criteria','name','evidence'];
        $total_data = Iqacdocumentupload::whereNull('deleted_at')->count();
        $limit = $request->input('length');
        $start = $request->input('start');
        $order = $col_order[$request->input('order.0.column')];
        $dir = $request->input('order.0.dir');
        $acyear = $request->get('acyear');
        $criteria = $request->get('criteria');
        
        $query  =   Iqacdocumentupload::join('iqac_documents','iqacupload_document.document_id','=','iqac_documents.id')->
                    join('iqac_criteria','iqacupload_document.criteria_id','=','iqac_criteria.id')->
                    join('users','iqacupload_document.staff_id','=','users.user_id');
        if($acyear!=''){
            $query->where('iqacupload_document.acyear_id',$acyear);
        }
        if($criteria!=''){
            $query->where('iqacupload_document.criteria_id',$criteria);
        }
        if(!empty($request->input('search.value'))){
            $search = $request->input('search.value');
            $query->where(function ($qry) use ($search){
                $qry->where('iqac_documents.document','like','%'.$search.'%')->
                orWhere('iqac_criteria.criteria','like','%'.$search.'%');
            });
        }
        $total_filtered = $query->count();
        $docupload = $query->select('iqacupload_document.*','iqac_documents.document','iqac_criteria.criteria','users.name')->offset($start)->limit($limit)->orderBy($order,$dir)->get();
        
        if(MenuAccess::have_access(158) == true){ $delete=1; }
        $data = array();
        if($docupload){
            foreach($docupload as $dqupld){ 
                $row['document'] = strtoupper($dqupld->document);
                $row['criteria'] = strtoupper($dqupld->criteria);
                $row['name'] = strtoupper($dqupld->name);
                $furl = asset('public/uploads/iqac/documents/'.$dqupld->evidence);
                $row['evidence'] = '<a href="'.$furl.'">Download</a>';
                    
                $html="";
                if($delete==1){
                    $html .= '<a href="'.route('fiqac.delete',encrypt($dqupld->id)).'" title="Delete" onClick="return confirm(\'Are you sure you want to delete?\');"><i class="icon-sm icon-trash text-danger"></i></a>';
                }
                $row['action'] = $html;
                
                $data[] = $row;
            }
        }
        
        $json = array(
            'draw' => intval($request->input('draw')),
            'recordsTotal' => intval($total_data),
            'recordsFiltered' => intval($total_filtered),
            'data' => $data
        );
        
        echo json_encode($json);
    }
     
     
    public function delete($qf_id){
        
        $iqacdoc = Iqacdocumentupload::find(decrypt($qf_id))->delete();
        if($iqacdoc){
            $msg_array = array('message'=>'Document Deleted Successfully !','alert-type'=>'success');
        }
        
        return redirect()->route('iqacrep')->with($msg_array);
    }
    
}
