<?php

namespace App\Http\Controllers;

use Illuminate\Http\Request;
use Illuminate\Support\Facades\Auth;
use Illuminate\Support\Facades\Log;

use App\Models\UserType;
use App\Models\User;
use App\Models\StaffAttendance;
use App\Models\AcHoliday;
use App\Models\Staffleaveset;

use DB;
use Carbon\Carbon;

class StaffAttendances extends Controller
{
    public function add(Request $request){
        try{
            $types = UserType::all();
            $typeId = $request->type ?? null;
            $date = $request->date ?? date('Y-m-d');
            
            $holiday = AcHoliday::where('start_date', '<=', $date)->where('end_date', '>=', $date)->where('staff', 1)->count();
            if($holiday == 0){
                $query = User::query();
                if($typeId!=null){
                    $query->where('type_id', $typeId);
                }
                $users = $query->orderBy('name', 'ASC')->get();
                $attendances = StaffAttendance::where('date', $date)->get();
                $staffs = [];
                foreach($users as $user){
                    $am=$pm='';
                    $atdata = $attendances->where('user_id', $user->user_id)->first();
                    if($atdata){
                        $am = $atdata->am;
                        $pm = $atdata->pm;
                    }
                     
                    $staffs[] = [
                            'id' => $user->user_id,
                            'eno' => $user->employee_id_num,
                            'name' => $user->name,
                            'desig' => $user->desig->type_name,
                            'am' => $am,
                            'pm' => $pm
                        ];
                }
                
                return view('staff-attendance.add', compact('types', 'typeId', 'date', 'staffs'));
            }else{
                return back()->with(['message'=>'Selected Date is Holiday !','alert-type'=>'error']);
            }
        } catch (\Exception $e) {
            Log::error('Failed to fetch Data: ' . $e->getMessage());
            return back()->with(['message'=>'Failed to load Data.','alert-type'=>'error']);
        }
    }
    
    public function details(Request $request){
        
        $date = $request->date ?? null;
        $stype = $request->stype ?? null;
        $staff_id = $request->sid ?? null;
        $ltypes = Staffleaveset::all();
        
        if($date!=null && $staff_id!=null){
            $staff = User::find($staff_id);
            
            $attendance = StaffAttendance::where('date', $date)->where('user_id', $staff_id)->first();
            $am=$pm=$lid=$reason='';
            if($attendance){
                $am = $attendance->am;
                $pm = $attendance->pm;
                $lid = $attendance->leave_id;
                $reason = $attendance->reason;
            }
            
            return view('staff-attendance.details',compact('date', 'stype', 'staff', 'attendance', 'am', 'pm', 'ltypes', 'lid', 'reason'));
        }
        
        return false;
    }
    
    public function leave(Request $request){
        try{
            $date = $request->date ?? null;
            $stype = $request->stype ?? null;
            $staff = $request->staff ?? null;
            $am = $request->has('am') ? 1 : 0;
            $pm = $request->has('pm') ? 1 : 0;
            $leave = $request->ltype ?? null;
            $reason = $request->reason ?? null;
            
            if($date!=null && $staff!=null){
                StaffAttendance::updateOrCreate([
                    'user_id' => $staff,
                    'date' => $date
                ],[
                    'am' => $am,
                    'pm' => $pm,
                    'leave_id' => $leave,
                    'reason' => $reason,
                ]);
                $msgArray = ['message'=>'Attendance Added Successfully !','alert-type'=>'success'];
            }else{
                $msgArray = ['message'=>'Attendance could not be Added !','alert-type'=>'error'];
            }
            
            return redirect()->route('staff.attendance',['type'=>$stype, 'date'=>$date])->with($msgArray);
            
        } catch (\Exception $e) {
            Log::error('Failed to fetch Data: ' . $e->getMessage());
            return back()->with(['message'=>'Failed to load Data.','alert-type'=>'error']);
        }
    }
    
    public function save(Request $request){
        try{
            $validated = $request->validate([
                    'date' => 'required|date',
                    'posted' => 'array|present',
                    'posted.*' => 'nullable|numeric'
                ]);
                
            foreach($validated['posted'] as $staff){
                StaffAttendance::firstOrCreate([
                        'user_id' => $staff,
                        'date' => $validated['date'],
                        'am' => 1,
                        'pm' => 1,
                    ]);
            }
            
            return redirect()->route('staff.attendance',['type'=>$request->stype, 'date'=>$validated['date']])->with(['message'=>'Attendance Added Successfully !','alert-type'=>'success']);
        } catch (\Exception $e) {
            Log::error('Failed to fetch Data: ' . $e->getMessage());
            return back()->with(['message'=>'Failed to load Data.','alert-type'=>'error']);
        }
    }
    
    public function report(Request $request){
        try{
            $types = UserType::all();
            $typeId = $request->type ?? null;
            $month = $request->month ?? date('Y-m');
            
            $carbonMonth = Carbon::parse($month);
            $startDate = (clone $carbonMonth)->startOfMonth();
            $endDate = (clone $carbonMonth)->endOfMonth();
           
            $query = User::query();
            if($typeId!=null){
                $query->where('type_id', $typeId);
            }
            $staffs = $query->orderBy('name', 'ASC')->get();
            
            $attendances = StaffAttendance::whereBetween('date',[$startDate->toDateString(), $endDate->toDateString()])->orderBy('date','ASC')->get();
            
            $data = [];
            foreach($attendances as $attendance){
                $data[$attendance->user_id][$attendance->date] = ['am' => $attendance->am, 'pm' => $attendance->pm, 'reason' => $attendance->reason];
            }
            
            $results = AcHoliday::whereDate('start_date', '<=', $endDate->toDateString())
                                ->whereDate('end_date', '>=', $startDate->toDateString())
                                ->where('staff', 1)
                                ->get();
            $holidays = [];
            foreach($results as $result){
                if($result->start_date==$result->end_date){
                    $holidays[] = $result->start_date;
                }else{
                    $hsDate = Carbon::parse($result->start_date);
                    $heDate = Carbon::parse($result->end_date);
                    while ($hsDate->lte($heDate)){
                        $hcDate = $hsDate->toDateString();
                        if(!in_array($hcDate, $holidays)){
                            $holidays[] = $hcDate;
                        }
                        $hsDate = $hsDate->addDay();
                    }
                }
            }
           
            $dates = [];
            while ($startDate->lte($endDate)){
                $dates[] = $startDate->toDateString();
                $startDate = $startDate->addDay();
            }
            
            return view('staff-attendance.report', compact('types', 'typeId', 'month', 'staffs', 'dates', 'attendances', 'data', 'holidays'));
            
        } catch (\Exception $e) {
            Log::error('Failed to fetch Data: ' . $e->getMessage());
            return back()->with(['message'=>'Failed to load Data.','alert-type'=>'error']);
        }
    }
}
