<?php

namespace App\Http\Controllers;

use Illuminate\Http\Request;
use App\Models\Student;
use App\Models\Acyear;
use App\Models\User;
use App\Models\ClassTeacher;
use App\Models\Promote;
use App\Models\BirthdayWishStu;
use App\Models\StaffTask;
use App\Models\StaffSubject;

use DB;
use Illuminate\Support\Facades\Auth;
 
class StaffDashboard extends Controller
{
    public function birthday_stu()
    {
        $user = Auth::user();
        $acyearId = getAcyear();
        
        $latestPromote = Promote::selectRaw('MAX(promote_id) as latest_id')->groupBy('student_id');
        
        $query = Promote::joinSub($latestPromote, 'latest_promotes', function ($join) {
                        $join->on('promotes.promote_id', '=', 'latest_promotes.latest_id');
                    })
                    ->join('students', 'promotes.student_id', '=', 'students.student_id')
                    ->join('courses', 'promotes.course_id', '=', 'courses.course_id')
                    ->join('semesters', 'promotes.semester_id', '=', 'semesters.semester_id')
                    ->where('promotes.ac_id', $acyearId);
        if($user->type_id==17) {
            $query->where('courses.department_id', $user->dept_id);
        } else {
            $semesters = ClassTeacher::where('ac_id', $acyearId)->where('user_id', $user->user_id)->pluck('semester_id')->unique()->values()->toArray();
            if(empty($semesters)) {
                $semesters = StaffSubject::where('acyear_id', $acyearId)->where('user_id', $user->user_id)->pluck('semester_id')->unique()->values()->toArray();
            }
            $query->whereIn('promotes.semester_id', $semesters);
        }
        
        $students = $query->whereRaw('DATE_FORMAT(students.dob, "%m-%d") = ?', [date('m-d')])->select('students.*','courses.course_name','semesters.semester_name')->get();
        
        return view('staffdashboard.birthday', compact('students'));
    }
   
    public function birthday_stu_msg(Request $request)
    {
        $student_id = Student::find($request->student_id);
        $userId = Auth::id();
        
        $message = $request->message;
        $exist = BirthdayWishStu::where('to',$student_id->student_id)->where('from',$userId)->exists();
        if(!$exist) {
            $wish = BirthdayWishStu::create([
                    'to'=>$student_id->student_id,
                    'from'=>$userId,
                    'message'=>$message,
                ]);
        }
        
        return redirect()->route('dash.birthday.student');
    }
   
    public function birthday_stu_count()
    {
        $user = Auth::user();
        $acyearId = getAcyear();
        
        $query = Promote::join('students', 'promotes.student_id', '=', 'students.student_id')
                    ->join('courses', 'promotes.course_id', '=', 'courses.course_id')
                    ->where('promotes.ac_id', $acyearId);
        if($user->type_id==17) {
            
            $semesters = ClassTeacher::where('ac_id', $acyearId)->where('user_id', $user->user_id)->pluck('semester_id')->unique()->values()->toArray();
            if($semesters) {
               $query->whereIn('promotes.semester_id', $semesters);
            }
            else
            {
            
            $query->where('courses.department_id', $user->dept_id);
            }
        } else {
            $semesters = ClassTeacher::where('ac_id', $acyearId)->where('user_id', $user->user_id)->pluck('semester_id')->unique()->values()->toArray();
            if(empty($semesters)) {
                $semesters = StaffSubject::where('acyear_id', $acyearId)->where('user_id', $user->user_id)->pluck('semester_id')->unique()->values()->toArray();
            }
            $query->whereIn('promotes.semester_id', $semesters);
        }
        
        $students = $query->distinct('promotes.student_id')->count('promotes.student_id');
        $bdays = $query->whereRaw('DATE_FORMAT(students.dob, "%m-%d") = ?', [date('m-d')])->distinct('promotes.student_id')->count('promotes.student_id');
        
        $data = array('0' => $bdays, '1' => $students);
        echo json_encode($data);
    }
   
    public function student_total()
    {
        return view('staffdashboard.student_total');
    }
   
    public function student_total_ajax(Request $request)
    {
        $col_order = ['adno','clno','name','fname','mname','mobile','course_name','semester_name'];
        $limit = $request->input('length');
        $start = $request->input('start');
        $order = $col_order[$request->input('order.0.column',1)];
        $dir = $request->input('order.0.dir');
        
        $user = Auth::user();
        $acyearId = getAcyear();
        
        $latestPromote = Promote::selectRaw('MAX(promote_id) as latest_id')->groupBy('student_id');
        
        $query = Promote::joinSub($latestPromote, 'latest_promotes', function ($join) {
                        $join->on('promotes.promote_id', '=', 'latest_promotes.latest_id');
                    })
                    ->join('students', 'promotes.student_id', '=', 'students.student_id')
                    ->join('courses', 'promotes.course_id', '=', 'courses.course_id')
                    ->join('semesters','promotes.semester_id','=','semesters.semester_id')
                    ->where('promotes.ac_id', $acyearId);
        if($user->type_id==17) {
            
            $semesters = ClassTeacher::where('ac_id', $acyearId)->where('user_id', $user->user_id)->pluck('semester_id')->unique()->values()->toArray();
            if($semesters) {
                //$semesters = StaffSubject::where('acyear_id', $acyearId)->where('user_id', $user->user_id)->pluck('semester_id')->unique()->values()->toArray();
                $query->whereIn('promotes.semester_id', $semesters);
            }
            else
            {
            
            $query->where('courses.department_id', $user->dept_id);
            }
        } else {
            $semesters = ClassTeacher::where('ac_id', $acyearId)->where('user_id', $user->user_id)->pluck('semester_id')->unique()->values()->toArray();
            if(empty($semesters)) {
                $semesters = StaffSubject::where('acyear_id', $acyearId)->where('user_id', $user->user_id)->pluck('semester_id')->unique()->values()->toArray();
            }
            $query->whereIn('promotes.semester_id', $semesters);
        }
        
        $total_data = $query->distinct('promotes.student_id')->count(); 
        
        if(!empty($request->input('search.value'))){
            $search = $request->input('search.value');
            $query->where(function ($qry) use ($search){
                $qry->where('adno','like','%'.$search.'%')
                    ->orWhere('rollno','like','%'.$search.'%')
                    ->orWhere('name','like','%'.$search.'%')
                    ->orWhere('fname','like','%'.$search.'%')
                    ->orWhere('mname','like','%'.$search.'%')
                    ->orWhere('mobile','like','%'.$search.'%')
                    ->orWhere('course_name','like','%'.$search.'%')
                    ->orWhere('semester_name','like','%'.$search.'%');
            });
        }
        
        $total_filtered = $query->distinct('promotes.student_id')->count();
        $students = $query->select('students.*','courses.course_name','semesters.semester_name')->offset($start)->limit($limit)->orderBy($order,$dir)->get();
        
        $data = array();
        if($students){
            foreach($students as $student){
                $row['adno'] = $student->adno;
                $row['rollno'] = $student->rollno;
                $row['name'] = '<a href="'.route('searchstudent.get.view', encrypt($student->student_id)).'" title="View" target="_blank"><u>' . wordwrap(strtoupper($student->name), 20, "<br />\n") . '</u></a>';
                $row['fathername'] = wordwrap(strtoupper($student->fname), 20, "<br />\n");
                $row['mothername'] = wordwrap(strtoupper($student->mname), 20, "<br />\n");
                $row['mobile'] = $student->mobile;
                $row['course'] = wordwrap(strtoupper($student->course_name), 20, "<br />\n");
                $row['semester'] = strtoupper($student->semester_name);
                
                $data[] = $row;
            }
        }
        
        $json = array(
            'draw' => intval($request->input('draw')),
            'recordsTotal' => intval($total_data),
            'recordsFiltered' => intval($total_filtered),
            'data' => $data
        );
            
        echo json_encode($json);
    }
    
    public function pending_task_total()
    { 
        $userId = Auth::id();
        $ac_id = getAcyear();
        $tasks = StaffTask::where([
                    'ac_id' => $ac_id,
                    'user_id' => $userId,
                    'status' => 0,
                ])->count();
        $data = array('0'=>$tasks);
        echo json_encode($data);
    }
    
    public function pending_task_staff()
    {
        $userId = Auth::id();
        $ac_id = getAcyear();
        
        $pendingtasks = StaffTask::where([
                    'ac_id' => $ac_id,
                    'user_id' => $userId,
                    'status' => 0,
                ])->get(); 
        
        return view('staffdashboard.Task.pending_task',compact('pendingtasks','ac_id'));
    }
    
    public function save_pendingtask(Request $request)
    {
        $ac_id = getAcyear();
        $userId = Auth::id();
        $i = 0;
        
        if (is_array($request->posted)) {
            foreach ($request->posted as $ids) {
                $check = StaffTask::where([
                    'id' => $ids,
                    'user_id' => $userId,
                ])->first();
                
                $status = $request->input("status" . $ids);
                $remark = $request->input("remark" . $ids);
                
                if ($check) {
                    $check->update([
                        'status' => $status,
                        'remark' => $remark,
                        'submitted_on'=>date('Y-m-d'),
                    ]);
                    $i++;
                }
            }
        }
        
        if ($i > 0) {
            $msg_array = ['message' => 'Task details have been submitted successfully!', 'alert-type' => 'success'];
        } else {
            $msg_array = ['message' => 'Task details could not be submitted!', 'alert-type' => 'error'];
        }
        
        return redirect()->route('home')->with($msg_array);
    }
}