<?php

namespace App\Http\Controllers\Student;

use App\Http\Controllers\Controller;
use Illuminate\Http\Request;
use Illuminate\Support\Facades\Log;
use Illuminate\Support\Facades\Auth;

use App\Models\Periods;
use App\Models\StudentAttendance;

use DB;
use Carbon\Carbon;

class Attendance extends Controller
{
    public function report(Request $request){
        try{
            $fdate = $request->input('fdate') ?? date('Y-m-d');
            $tdate = $request->input('tdate') ?? date('Y-m-d');
            
            $studentId = Auth::guard('student')->id();
            
            $acyearId = getAcyear();
            $periods = Periods::where('acyear', $acyearId)->get();
            
            $attendances = StudentAttendance::whereBetween('date', [$fdate, $tdate])->where('student_id', $studentId)->select('date', 'period_id', 'status')->groupBy('date', 'period_id')->get();
            $data = $dates = [];
            
            $startDate = Carbon::createFromFormat('Y-m-d', $fdate);
            $endDate = Carbon::createFromFormat('Y-m-d', $tdate);
            while($startDate->lte($endDate)) {
                $dateString = $startDate->toDateString();
                $dates[] = $dateString;
                $startDate->addDay();
            }
            
            foreach($attendances as $attendance){
                $data[$attendance->date][$attendance->period_id] = $attendance->status;
            }
            
            return view('student.attendance.report', compact('fdate', 'tdate', 'periods', 'dates', 'data'));
        } catch (\Exception $e) {
            Log::error('Failed to fetch Attendance: '.$e->getMessage());
            return back()->withErrors('Failed to load Attendance.');
        }
        
    }
    
}