<?php

namespace App\Models;

use Illuminate\Database\Eloquent\Factories\HasFactory;
use Illuminate\Database\Eloquent\Model;
use Illuminate\Database\Eloquent\SoftDeletes;
use Illuminate\Foundation\Auth\User as Authenticatable;
use Laravel\Sanctum\HasApiTokens;

class Student extends Authenticatable
{
    use HasApiTokens, HasFactory, SoftDeletes;
    
    protected $table = 'students';
    
    protected $primaryKey = 'student_id'; 
    
    protected $guarded = [];
    
    protected $hidden = ['student_id'];
    
    public function getStatusTextAttribute(){
        if($this->status=='1') return "Active";
        else if($this->status=='0') return "Inactive";
    }
    
    public function getDobFormattedAttribute(){
        return date('d/m/Y',strtotime($this->dob));
    }
    
    public function getAdateFormattedAttribute(){
        return date('d/m/Y',strtotime($this->adate));
    }
    
    protected $appends = ['status_text','dob_formatted','adate_formatted'];
    
    
    public function acyear(){
        return $this->hasOne(Acyear::class,'ac_id','ac_id');
    }
    
    public function course(){
        return $this->hasOne(Course::class,'course_id','course_id');
    }
    public function majorii(){
        return $this->belongsTo(Course::class,'major_ii','course_id')->withDefault(['name' => '']);
    }
    public function categ(){
        return $this->hasOne(FeeCategory::class,'category_id','category_id');
    }
    
    public function semester(){
        return $this->belongsTo(Semester::class,'semester_id','semester_id')->withDefault(['name' => '']);
    }
     public function promotes(){
        return $this->hasmany(Promote::class,'student_id','student_id');
    }
    public function spcl()
    {
        return $this->hasOne(Electives::class,'student_id','student_id');
    }
     public function scholarship()
    {
        return $this->hasOne(ScholarshipStudent::class,'student_id','student_id');
    }
    public function community()
    {
        return $this->hasOne(Community::class,'community_id','community_id');
    }
     public function caste()
    {
        return $this->hasOne(Caste::class,'caste_id','caste_id');
    }
     public function religion()
    {
        return $this->hasOne(Religion::class,'religion_id','religion_id');
    }
    public function sem()
    {
        return $this->hasOne(Semester::class,'semester_id','semester_id');
    }
    
     public function quota()
    {
        return $this->hasOne(acquotamodel::class,'aq_id','aq_id');
    }
      public function quotaaa()
    {
        return $this->hasOne(acquotamodel::class,'aq_id','quota');
    }
    
     public function universitysubmark(){
        return $this->hasmany(ObeMarkList::class,'stud_id','student_id');
    }
    
    public function internalmark(){
        return $this->hasmany(ObeStudMarkList::class,'stud_id','student_id');
    }
   public function isAbsent($date)
{
    
    return $this->attendances()
                ->where('date', $date)
                ->where('am', 1) 
                ->where('pm', 1)             
                ->exists();
} 
 public function staff()
    {
        return $this->hasOne(User::class,'user_id','user_id');
    }
     public function subject()
    {
        return $this->hasOne(Subject::class,'subject_id','subject_id');
    }
    
    
    
    
    
}
