@extends('layouts.template')
@section('title','Department Time Table')
@section('heading','Department Time Table')
@section('breadcrumb','Home / Time Table / Department')
@section('content')
    <style>
        .timetable {
            text-transform: uppercase;
            text-align: center;
            align-items: center;
            font-size: 13px;
        }
        .tt-row{
            display: flex;
            gap: 10px;
        }
        .tt-block {
            flex: 1 1 calc(100% / 7);
        }
        .tt-period {
            background-color: #2D2870;
            color: #FFF;
            font-weight: 700;
            padding: 10px 15px;
            border-radius: 10px;
            margin: 5px 0;
        }
        .tt-day {
            background-color: #DC4F4B;
            color: #FFF;
            font-weight: 700;
            padding: 10px 15px;
            border-radius: 10px;
            margin: 5px 0;
            height: auto;
            min-height: 180px;
            align-items: center;
        }
        .tt-content {
            background-color: #F1FAEE;
            border-radius: 10px;
            margin: 5px 0;
            padding: 5px;
            height: auto;
            min-height: 180px;
        }
        .tt-item {
            background-color: #c7e9ff;
            border-radius: 5px;
            margin: 3px 0;
        }
        .tt-item:hover {
            cursor: pointer;
        }
        .tt-inter {
            background-color: #eec7ff;
        }
        .tt-category {
            font-weight: 600;
        }
        .tt-user {
            
        }
        .tt-button {
            background-color: green;
            color: #FFF;
            padding: 2px 10px;
            border: 0px;
            border-radius: 5px;
        }
        
        @media (max-width: 480px) {
            .tt-row{
                gap: 5px;
            }
            .tt-block {
                flex: 1 1 100%;
            }
        }
    </style>
    <div class="card">
        <div class="card-body">
            <form method="get">
                <div class="row">
                    <div class="col-12 col-sm-8">
                        <div class="form-group">
                            <label for="department" class="required">Department</label>
                            <div class="row">
                                <div class="col-12 col-sm-6">
                                    <div class="form-group">
                                        <select class="form-control" id="department" name="department" required>
                                            <option value="">Select</option>
                                            @foreach($departments as $department)
                                                <option value="{{ $department->id }}" {{ $department->id==$departmentId ? 'selected':'' }}>{{ $department->dept_name }}</option>
                                            @endforeach
                                        </select>
                                        @error('department')<div class="text-daborder-danger small mt-1 text-danger">{{ $message }}</div>@enderror
                                    </div>
                                </div>
                                <div class="col-12 col-sm-6">
                                    <div class="form-group">
                                        <button type="submit" class="btn btn-sm btn-success">Submit</button>
                                    </div>
                                </div>
                            </div>
                        </div>
                    </div>
                </div>
            </form>
        </div>
    </div>
    @if(!empty($data))
        <br>
        <div class="card">
            <div class="card-body">
                <div class="row">
                    <div class="col-12 text-center">
                        <h4>{{ $depart ? $depart->dept_name . ' DEPARTMENT' : '' }}</h4>
                    </div>
                </div>
                <div class="timetable">
                    <div class="tt-row">
                        <div class="tt-block">
                            <div class="tt-head"></div>
                        </div>
                        @foreach($periods as $period)
                            <div class="tt-block">
                                <div class="tt-period">{{ $period->period }}</div>
                            </div>
                        @endforeach
                    </div>
                    @foreach($days as $day)
                        <div class="tt-row">
                            <div class="tt-block">
                                <div class="tt-day">{{ $day->day }}</div>
                            </div>
                            @foreach($periods as $period)
                                <div class="tt-block">
                                    <div class="tt-content">
                                        @if(!empty($data[$day->day][$period->id]))
                                            @foreach($data[$day->day][$period->id] as $detail)
                                                <div class="tt-item">
                                                    <div>{{ $detail['semester'] }}</div>
                                                    <div class="tt-category">
                                                        {{ $detail['category'] }}
                                                        @if($detail['type']==1) 
                                                            {{ ' - PR' }}
                                                        @endif
                                                    </div>
                                                    <div class="tt-user">
                                                        @if($detail['group']!='')
                                                            {{ $detail['group'].' - ' }}
                                                        @endif
                                                        {{ $detail['scode'] }}
                                                    </div>
                                                </div>
                                            @endforeach
                                        @endif
                                    </div>
                                </div>
                            @endforeach
                        </div>
                    @endforeach
                </div>
                <br>
                <div class="row">
                    @foreach($staffs as $staff)
                        <div class="col-12 col-sm-4">
                            <div class="form-group">
                                <span class="text-danger">{{ strtoupper($staff->code) }} : </span>{{ strtoupper($staff->name) }}
                            </div>
                        </div>
                    @endforeach
                </div>
            </div>
        </div>
    @endif
@endsection