@extends('layouts.template')
@section('title','Home')
@section('heading','Fee Report')
@section('breadcrumb','Home/Hostel/Fee Report')
@section('content')





    <div class="row">
        <div class="col-lg-12 grid-margin stretch-card">
            <div class="card">
                <div class="card-header" style="background: #005A9C;color:white;"><b>Select the Criteria</b></div>
                <div class="card-body">
                    <div class="row">
                        <div class="col-md-3">
                            <div class="form-group">
                                <label for="fdate"><b>From Date</b></label>
                                <input type="date" class="form-control" id="fdate" name="fdate" value="{{ old('fdate') ? old('fdate'):date('Y-m-d') }}">
                                @error('fdate')<div class="text-daborder-danger small mt-1 text-danger">{{ $message }}</div>@enderror
                            </div>
                        </div>
                        <div class="col-md-3">
                            <div class="form-group">
                                <label for="tdate"><b>To Date</b></label>
                                <input type="date" class="form-control" id="tdate" name="tdate" value="{{ old('tdate') ? old('tdate'):date('Y-m-d') }}">
                                @error('tdate')<div class="text-daborder-danger small mt-1 text-danger">{{ $message }}</div>@enderror
                            </div>
                        </div>
                        <div class="col-md-3">
                            <div class="form-group">
                                <label for="course"><b>Program</b></label>
                                <select class="js-example-basic-single" style="width:100%" id="course" name="course">
                                    <option value="">Select</option>
                                    @foreach($courses as $course)
                                        <option value="{{ $course->course_id }}" {{ old('course')==$course->course_id ? "selected":"" }}>{{ $course->course_name }}</option>
                                    @endforeach
                                </select>
                                @error('course')<div class="text-daborder-danger small mt-1 text-danger">{{ $message }}</div>@enderror
                            </div>
                        </div>
                        <div class="col-md-3">
                            <div class="form-group">
                                <label for="ftype"><b>Fee Type</b></label>
                                <select class="js-example-basic-single" id="ftype" name="ftype" style="width:100%">
                                    <option value="">Select</option>
                                    <option value="1" {{ old('ftype') == 1 ? "selected":"" }}>Rent</option>
                                    <option value="2" {{ old('ftype') == 2 ? "selected":"" }}>Mess Fee</option>
                                </select>
                                @error('ftype')<div class="text-daborder-danger small mt-1 text-danger">{{ $message }}</div>@enderror
                            </div>
                        </div>
                    </div>
                    <div class="row">
                        <div class="col-md-3">
                            <div class="form-group">
                                <label for="mode"><b>Payment Mode</b></label>
                                <select class="js-example-basic-single" id="mode" name="mode" style="width:100%">
                                    <option value="">Select</option>
                                    @foreach($paymodes as $paymode)
                                        <option value="{{ $paymode->mode_id }}" {{ old('mode') == $paymode->mode_id ? "selected":"" }}>{{ $paymode->mode_name }}</option>
                                    @endforeach
                                </select>
                                @error('mode')<div class="text-daborder-danger small mt-1 text-danger">{{ $message }}</div>@enderror
                            </div>
                        </div>
                        <div class="col-md-6">
                            <div class="form-group">
                                <label for="staff"><b>Collected By</b></label>
                                <div class="row">
                                    <div class="col-md-6">
                                        <select class="js-example-basic-single" style="width:100%" id="staff" name="staff">
                                            <option value="">Select</option>
                                            @foreach($staffs as $staff)
                                                <option value="{{ $staff->user_id }}" {{ old('staff')==$staff->user_id ? "selected":"" }}>{{ $staff->name }}</option>
                                            @endforeach
                                        </select>
                                        @error('staff')<div class="text-daborder-danger small mt-1 text-danger">{{ $message }}</div>@enderror
                                    </div>
                                    <div class="col-md-6">
                                        <button type="button" class="btn btn-primary" id="getData">Filter</button>
                                    </div>
                                </div>
                            </div>
                        </div>
                    </div>
                </div>
            </div>
        </div>
    </div>
    <div class="row">
        <div class="col-lg-12 grid-margin stretch-card">
            <div class="card">
                <div class="card-header" style="background: #004170;color:white;"><b>Hostel Fee Report</b></div> 
                <div class="card-body">
                    <table class="table table-bordered" id="dueTable" width="100%">
                        <thead>
                        <tr>
                            <th><b>Rec No</b></th>
                            <th><b>Date</b></th>
                            <th><b>Adm No</b></th>
                            <th><b>Name</b></th>
                            <th><b>Program</b></th>
                            <th><b>Semester</b></th>
                            <th class="no-sort aright"><b>Paid Amount</b></th>
                            <th><b>Collected By</b></th>
                            <th class="no-sort"><b>Action</b></th>
                        </tr>
                        </thead>
                        <tbody>
                        </tbody>
                    </table>
                    <div class="row">
                        <div class="col-8 text-right font-weight-bold">Total :</div>
                        <div class="col-4 font-weight-bold" id="total">0.00</div>
                    </div>
                </div>
            </div>
        </div>
    </div>
    
    
    
    
     
    <script src="{{ asset('public/template/plugins/jquery/jquery.min.js') }}"></script>
    <script src="{{ asset('public/js/fee.js') }}"></script>
    <script>
        $(function () {
            var dueTable = $("#dueTable").DataTable({
                lengthChange: true,
                scrollX: true,
                searching: true,
                processing : true,
                serverSide : true,
                columnDefs : [{ targets: 'no-sort', orderable: false },{ targets: 'aright', className: 'text-right'}],
                ajax : {
                    url : '{{ route('hostelpayment.report.ajax') }}',
                    dataType : 'json',
                    type : 'GET',
                    data: function(data){
                        data.course = $('#course').val();
                        data.semester = $('#semester').val();
                        data.fdate = $('#fdate').val();
                        data.tdate = $('#tdate').val();
                        data.mode = $('#mode').val();
                        data.ftype = $('#ftype').val();
                        data.staff = $('#staff').val();
                    }
                },
                columns : [
                    { data : 'recno' },
                    { data : 'date' },
                    { data : 'adno' },
                    { data : 'name' },
                    { data : 'course' },
                    { data : 'semester' },
                    { data : 'amount' },
                    { data : 'collected' },
                    { data : 'action' },
                ]
            });
            $('#getData').click(function(){
                dueTable.draw();
                get_total();
            });
            get_total();
        });
        
        function get_total(){
            var course = $('#course').val();
            var semester = $('#semester').val();
            var fdate = $('#fdate').val();
            var tdate = $('#tdate').val();
            var mode = $('#mode').val();
            var ftype = $('#ftype').val();
            var staff = $('#staff').val();
            
            $.ajax({
                type: "GET",
                url: '{{ route('hostel.total.ajax') }}',
                data: { course:course, semester:semester, fdate:fdate, tdate:tdate, mode:mode, ftype:ftype, staff:staff },
                cache: false,
                success: function(data){
                    $("#total").text(data);
                }
            });
        }
    </script>
    <style>
         .card-body{
            border-left:1px solid #DCDCDC;
            border-right:1px solid #DCDCDC;
            border-bottom:1px solid #DCDCDC;
          
        }
     
      
        .form-control{
            border:1px solid #E8E8E8;
        }
        table.table-bordered tr:hover {background-color: #B9D9EB;cursor:pointer;}
    </style>
@endsection