@extends('layouts.template')
@section('title','Logins')
@section('heading','Student Logins')
@section('breadcrumb','Home / Logins / Student')
@section('content')
@if ($errors->any())
    <div class="alert alert-danger">
        <ul>
            @foreach ($errors->all() as $error)
                <li>{{ $error }}</li>
            @endforeach
        </ul>
    </div>
@endif


    <div class="card">
        <div class="card-body">
            <form method="get">
                <div class="row">
                    <div class="col-12 col-sm-3">
                        <div class="form-group">
                            <label for="course">Program</label>
                            <select class="js-example-basic-single" id="course" name="course" style="width:100%" required>
                                <option value="">Select</option>
                                @foreach($courses as $course)
                                    <option value="{{ $course->course_id }}" {{ $course->course_id == $courseId ? "selected":"" }}>{{ $course->course_name }}</option>
                                @endforeach
                            </select>
                        </div>
                    </div>
                    <div class="col-12 col-sm-6">
                        <div class="form-group">
                            <label for="semester">Semester</label>
                            <div class="row">
                                <div class="col-12 col-sm-6">
                                    <div class="form-group">
                                        <select class="js-example-basic-single" id="semester" name="semester" style="width:100%">
                                            <option value="">Select</option>
                                            @foreach($semesters as $semester)
                                                <option value="{{ $semester->semester_id }}" {{ $semester->semester_id == $semesterId ? "selected":"" }}>{{ $semester->semester_name }}</option>
                                            @endforeach
                                        </select>
                                    </div>
                                </div>
                                <div class="col-12 col-sm-6">
                                    <div class="form-group">
                                        <button type="submit" class="btn btn-sm btn-success">Submit</button>
                                    </div>
                                </div>
                            </div>
                        </div>
                    </div>
                </div>
            </form>
        </div>
    </div>
    <br>
    @if($students->count() > 0)
        <div class="card">
            <div class="card-body">
                <div class="row">
                    <div class="col-md-12">
                        <div class="form-group">
                            <a href="{{ route('logins.student.print', ['course' => $courseId, 'semester' => $semesterId]) }}" class="btn btn-sm btn-success btn-icon-text" target="_blank">
                                <i class="icon-printer btn-icon-prepend"></i> Print
                            </a>
                            <a href="{{ route('logins.student.send', ['course' => $courseId, 'semester' => $semesterId]) }}" class="btn btn-sm btn-info btn-icon-text" target="_blank">
                                <i class="icon-envelope-letter btn-icon-prepend"></i> Send Mail
                            </a>
                        </div>
                    </div>
                </div>
                <div class="scroll">
                    <table class="table table-bordered">
                        <thead>
                        <tr>
                            <th>#</th>
                            <th>Adm No</th>
                            <th>Student Name</th>
                            <th>Mobile</th>
                            <th>Email</th>
                            <th>Status</th>
                            <th>Action</th>
                        </tr>
                        </thead>
                        <tbody>
                            @foreach($students as $student)
                                <tr>
                                    <td align="center">{{ $loop->iteration }}</td>
                                    <td align="center">{{ $student->adno }}</td>
                                    <td>{{ $student->name }}</td>
                                    <td align="center">{{ $student->mobile }}</td>
                                    <td align="center">{{ $student->email }}</td>
                                    <td align="center">{{ $student->status==0 ? 'Blocked':'Active' }}</td>
                                    <td align="center">
                                        <a href="{{ route('logins.student.edit',['student_id' => encrypt($student->student_id), 'course' => $courseId, 'semester' => $semesterId]) }}" title="Edit"><i class="icon icon-pencil text-primary"></i></a>&nbsp;&nbsp;&nbsp;
                                        @if($student->status==1)
                                            <a href="{{ route('logins.student.block',['student_id' => encrypt($student->student_id), 'status' => 0, 'course' => $courseId, 'semester' => $semesterId]) }}" title="Block"><i class="icon icon-lock text-danger"></i></a>
                                        @else
                                            <a href="{{ route('logins.student.block',['student_id' => encrypt($student->student_id), 'status' => 1, 'course' => $courseId, 'semester' => $semesterId]) }}" title="Unblock"><i class="icon icon-lock-open text-success"></i></a>
                                        @endif
                                    </td>
                                </tr>
                            @endforeach
                        </tbody>
                    </table>
                </div>
            </div>
        </div>
    @else
        <div class="alert alert-danger">No Result Found !</div>
    @endif
    <script src="{{ asset('public/js/general.js') }}"></script> 
@endsection