@extends('layouts.settings-template')
@section('title','Settings')
@section('heading','Staff Course')
@section('breadcrumb','Settings / Staff Setting /Staff Course')
@section('content')
    <div class="card card-primary">
        <div class="card-header">Assign Course to Staff</div>
        <div class="card-body">
            <form action="{{ route('staffsubject.save') }}" method="post">
                @csrf
                <input type="hidden" id="usertype" value="{{ $user_type }}">
                <input type="hidden" id="dept_id" value="{{ $dept_id }}">
                <div class="row">
                    <div class="col-12 col-md-3">
                        <div class="form-group">
                            <label for="user_id" class="required">Staff</label>
                            <select class="js-example-basic-single form-control" id="user_id " name="user_id" required>
                                <option value="">Select</option>
                                @foreach($user as $users)
                                    <option value="{{ $users->user_id }}" {{ old('user_id')==$users->user_id ? "selected":"" }}>{{ $users->name }}</option>
                                @endforeach
                            </select>
                            @error('user_id')<div class="text-daborder-danger small mt-1 text-danger">{{ $message }}</div>@enderror
                        </div>
                    </div>
                    <div class="col-12 col-md-3">
                        <div class="form-group">
                            <label for="course_id" class="required"><b>Program</b></label>
                            <select class="form-control" id="course_id" name="course_id" required>
                                <option value="">Select</option>
                                @foreach($course as $crs)
                                    <option value="{{ $crs->course_id }}" {{ old('course_id')==$crs->course_id ? "selected":"" }}>{{ $crs->course_name }}</option>
                                @endforeach
                            </select>
                            @error('course_id')<div class="text-daborder-danger small mt-1 text-danger">{{ $message }}</div>@enderror
                        </div>
                    </div>
                    <div class="col-12 col-md-3">
                        <div class="form-group">
                            <label for="semester_id" class="required">Semester</label>
                            <select class="form-control" id="semester_id" name="semester_id" required>
                                <option value="">Select</option>
                            </select>
                            @error('semester_id')<div class="text-daborder-danger small mt-1 text-danger">{{ $message }}</div>@enderror
                        </div>
                    </div>
                    <div class="col-12 col-md-3">
                        <div class="form-group">
                            <label for="subject_id" class="required">Course</label>
                            <select class="js-example-basic-single form-control" id="subject_id" name="subject_id" required>
                                <option value="">Select</option>
                            </select>
                            @error('subject_id')<div class="text-daborder-danger small mt-1 text-danger">{{ $message }}</div>@enderror
                        </div>
                    </div>
                </div>
                <div class="row">
                    <div class="col-12">
                        <div class="form-group">
                            <button type="submit" class="btn btn-success float-right">Save</button>
                        </div>
                    </div>
                </div>
            </form>
        </div>
    </div>
    <br>
    <div class="card">
        <div class="card-body">
            <div class="row">
                <div class="col-12">
                    <div class="form-group">
                        @if($export)
                            <button type="button" class="btn btn-sm btn-success" id="export"><i class="icon-cloud-download"></i> Export Staff Course</button>
                        @endif
                    </div>
                </div>
            </div>
            <table class="table table-bordered">
                <thead>
                <tr>
                    <th>#</th>
                    <th>Staff Name</th>
                    <th>Program</th>
                    <th>Semester</th>
                    <th>Category</th>
                    <th>Course</th>
                    <th>Actions</th>
                </tr>
                </thead>
                <tbody>
                    @php  $i=0; @endphp
                    @forelse($staffsubject as $stfsub)
                    @php $i++; @endphp
                        <tr>
                            <td>{{$i;}}</td>
                            <td>{{ $stfsub->user->name }}</td>
                            <td>{{ $stfsub->course->course_name }}</td>
                            <td>{{ $stfsub->semester->semester_name }}</td>
                            <td>{{ $stfsub->category->category ?? 'No Category' }}</td>
                            
                            <td style="word-wrap: break-word; word-break: break-all; white-space: normal;">{{$stfsub->subject->subject_name}}</td>
                            <td>{{ app_table_links($stfsub->stfsub_id,array(723)) }}</td>
                        </tr>
                    @empty
                        <tr>
                            <td colspan="2">No Result Found !</td>
                        </tr>
                    @endforelse
                </tbody>
            </table>
        </div>
    </div>
    <script src="{{ asset('public/template/plugins/jquery/jquery.min.js') }}"></script>
    <script src="{{ asset('public/js/sem.js') }}"></script>
    <script src="{{ asset('public/js/subtyp.js') }}"></script>
    <script>
        $(function () {
            $('#export').click(function(){
                var usertype = $('#usertype').val();
                var dept_id = $('#dept_id').val();
                window.location = '/staffsubject-export?usertype='+usertype+'&dept_id='+dept_id;
            });
        });
    </script>
@endsection