@extends('layouts.template')
@section('title','Attendance')
@section('heading','Attendance')
@section('breadcrumb','Home / Student / Class Attendance')
@section('content')
    <style>
        .scroll {
            overflow-x: auto;
            -webkit-overflow-scrolling: touch; /* Smooth scrolling for iOS */
        }
        
        table {
            width: 100%;
            table-layout: auto; /* Adjust column width dynamically */
            border-collapse: collapse; /* Optional: Better appearance */
        }
        
        td {
            word-wrap: break-word; /* Break long words */
            overflow-wrap: anywhere; /* Modern breaking */
            hyphens: auto; /* Hyphenation for long words */
        }
        
        th, td {
            white-space: normal; /* Allow wrapping */
            word-break: break-word; /* Break long words */
            text-align: center; /* Align content */
            padding: 5px; /* Add padding for readability */
        }
        
        th {
            background-color: #f5f5f5; /* Light gray header background */
            white-space: nowrap; /* Prevent header wrapping */
        }
        
        .trheight > td {
            line-height: 28px;
        }
        .subject{
            font-size: 12px;
            font-weight: bold;
            color: #000;
        }
        
        a{
            text-decoration: none;
        }
        a:hover {
            text-decoration: none;
        }
        .pblock:hover{
            background-color: #bdf4ff;
        }
        .bg-light-purple {
            background-color: #fabfff; 
        }
        
        @media (max-width: 768px) {
            table {
                font-size: 12px; /* Scale font down for mobile */
            }
            .trheight > td {
                font-size: 10px; /* Reduce font size for mobile */
            }
        }
    </style>
    <div class="card">
        <div class="card-body">
            <form method="get">
                <div class="row">
                    <div class="col-12 col-sm-3">
                        <div class="form-group">
                            <label for="course" class="required">Program</label>
                            <select class="form-control" id="course" name="course">
                                <option value="">Select</option>
                                @foreach($courses as $course)
                                    <option value="{{ $course->course_id }}" {{ $course->course_id==$courseId ? 'selected':'' }}>{{ $course->course_name }}</option>
                                @endforeach
                            </select>
                        </div>
                    </div>
                    <div class="col-12 col-sm-3">
                        <div class="form-group">
                            <label for="semester" class="required">Semester</label>
                            <select class="form-control" id="semester" name="semester">
                                <option value="">Select</option>
                                @foreach($semesters as $semester)
                                    <option value="{{ $semester->semester_id }}" {{ $semester->semester_id==$semesterId ? 'selected':'' }}>{{ $semester->semester_name }}</option>
                                @endforeach
                            </select>
                        </div>
                    </div>
                    <div class="col-12 col-sm-6">
                        <div class="form-group">
                            <label for="date" class="required">Date</label>
                            <div class="row">
                                <div class="col-12 col-sm-6">
                                    <div class="form-group">
                                        <input type="date" class="form-control" id="date" name="date" value="{{ $date }}" required>
                                        @error('date')<div class="text-daborder-danger small mt-1 text-danger">{{ $message }}</div>@enderror  
                                    </div>
                                </div>
                                <div class="col-12 col-sm-6">
                                    <div class="form-group">
                                        <button type="submit" class="btn btn-sm btn-success">Submit</button>
                                    </div>
                                </div>
                            </div>   
                        </div>
                    </div>
                </div>
            </form>
        </div>
    </div>
    <br>
    @if(!empty($data))
        <div class="card">
            <div class="card-body">
                <div class="row">
                    <div class="col-12 col-sm-2">
                        <div class="form-group d-flex">
                            <div class="square bg-light-red"></div> Holiday
                        </div>
                    </div>
                    <div class="col-12 col-sm-2">
                        <div class="form-group d-flex">
                            <div class="square bg-light-green"></div> Completed
                        </div>
                    </div>
                    <div class="col-12 col-sm-2">
                        <div class="form-group d-flex">
                            <div class="square bg-light-orange"></div> Pending
                        </div>
                    </div>
                    <div class="col-12 col-sm-2">
                        <div class="form-group d-flex">
                            <div class="square bg-light-purple"></div> Substitution
                        </div>
                    </div>
                </div>
                <div class="row">
                    <div class="col-12 scroll">
                        <table class="table table-bordered">
                            <thead>
                            <tr>
                                <th width="10%">Hour</th>
                                @foreach($dates as $date)
                                    <th width="15%"><b>{{ date('l',strtotime($date)) }}<br><br>{{ date('d/m/Y',strtotime($date)) }}</b></th>
                                @endforeach
                            </tr>
                            </thead>
                            <tbody>
                                @foreach($periods as $period)
                                    <tr class="trheight">
                                        <td align="center">{{ $period->period }}</td>
                                        @foreach($dates as $date)
                                            @if(isset($data[$date][$period->id]))
                                             <td>
                                            @foreach($data[$date][$period->id] as $timp)
                                                @php
                                                    $course = $timp['course_id'];
                                                    $semester = $timp['semester_id'];
                                                    $subject = $timp['subject_id'];
                                                    $staff = $timp['staff_id'];
                                                @endphp
                                                <div class="pblock @if($timp['holiday']>0) bg-light-red @elseif($timp['marked']==1) bg-light-green @elseif($timp['marked']==2) bg-light-orange @elseif($timp['type']==1) bg-light-purple @endif" align="center">
                                                    <a href="{{ route('staff.student.attendance.all.add',['date'=>$date, 'course'=>$course, 'semester'=>$semester, 'subject'=>$subject, 'period'=>$period->id, 'staff'=>$staff ]) }}">
                                                        <div class="period">
                                                            <div class="subject">{{ strtoupper($timp['subject_name']) }}</div>
                                                            <div class="course text-success">{{ strtoupper($timp['course_name']) }}</div>
                                                            <div class="semester text-danger">{{ strtoupper($timp['semester_name']) }}</div>
                                                            <div class="staff text-primary">{{ strtoupper($timp['staff_name']) }}</div>
                                                        </div>
                                                    </a>
                                                </div>
                                                @endforeach
                                                </td>
                                            @else
                                                <td class="pblock " align="center"></td>
                                            @endif
                                        @endforeach
                                    </tr>
                                @endforeach
                            </tbody>
                        </table>
                    </div>
                </div>
            </div>
        </div>
    @else    
        <div class="alert alert-danger">No Result Found !</div>
    @endif
    <script src="{{ asset('public/js/class-teacher.js?ver=1.2') }}"></script>
@endsection