@extends('layouts.template')
@section('title','Attendance')
@section('heading','Consolidate Attendance')
@section('breadcrumb','Home / Student / Attendance')
@section('content')
    <div class="card">
        <div class="card-body">
            <form method="get">
                <div class="row">
                    <div class="col-12 col-sm-3">
                        <div class="form-group">
                            <label for="course">Program</label>
                            <select class="form-control js-example-basic-single" id="course" name="course">
                                <option value="">Select</option>
                                @foreach($courses as $course)
                                    <option value="{{ $course->course_id }}" {{ $course->course_id==$courseId ? "selected":"" }}>{{ $course->course_name }}</option>
                                @endforeach
                            </select>
                            @error('course')<div class="text-daborder-danger small mt-1 text-danger">{{ $message }}</div>@enderror
                        </div>
                    </div>
                    <div class="col-12 col-sm-3">
                        <div class="form-group">
                            <label for="semester">Semester</label>
                            <select class="form-control js-example-basic-single" id="semester" name="semester">
                                <option value="">Select</option>
                                @foreach($semesters as $semester)
                                    <option value="{{ $semester->semester_id }}" {{ $semester->semester_id==$semesterId ? "selected":"" }}>{{ $semester->semester_name }}</option>
                                @endforeach
                            </select>
                            @error('semester')<div class="text-daborder-danger small mt-1 text-danger">{{ $message }}</div>@enderror
                        </div>
                    </div>
                    <div class="col-12 col-sm-6">
                        <div class="form-group">
                            <label for="month">Month</label>
                            <div class="row">
                                <div class="col-12 col-sm-6">
                                    <div class="form-group">
                                        <input type="month" class="form-control" id="month" name="month" value="{{ $month }}">
                                        @error('month')<div class="text-daborder-danger small mt-1 text-danger">{{ $message }}</div>@enderror
                                    </div>
                                </div>
                                <div class="col-12 col-sm-6">
                                    <div class="form-group">
                                        <button type="submit" class="btn btn-sm btn-success">Submit</button>
                                    </div>
                                </div>
                            </div>
                        </div>
                    </div>
                </div>
            </form>
        </div>
    </div>
    <br>
    @if(collect($students)->isNotEmpty())
        <div class="card">
            <div class="card-body">
                <div class="row">
                    <div class="col-12">
                        <div class="form-group text-center">
                            <h5>{{ date('F Y',strtotime($month)) }}</h5>
                        </div>
                    </div>
                </div>
                <div class="row">
                    <div class="col-12">
                        <div class="form-group">
                            <a href="{{ route('student.attendance.consolidate.export', ['course' => $courseId, 'semester' => $semesterId, 'month' => $month]) }}" class="btn btn-sm btn-success" target="_blank">Export</a>
                        </div>
                    </div>
                </div>
                <div class="row">
                    <div class="col-12">
                        <div class="scroll">
                            <table class="table table-bordered">
                                <thead>
                                <tr>
                                    <th width="5%" rowspan="2">#</th>
                                    <th width="10%" rowspan="2">Adm No.</th>
                                    <th width="10%" rowspan="2">Roll No.</th>
                                    <th rowspan="2">Name</th>
                                    @php $totalHours=0; @endphp
                                    @foreach($subjects as $subject)
                                        <th colspan="2">{{ $subject['name'] }}<br><br>{{ $subject['hours'] }}</th>
                                    @endforeach
                                    <th colspan="2">Total</th>
                                </tr>
                                <tr>
                                    @foreach($subjects as $subject)
                                        <th width="5%">Present</th>
                                        <th width="5%">%</th>
                                    @endforeach
                                    <th width="5%">Present</th>
                                    <th width="5%">%</th>
                                </tr>
                                </thead>
                                <tbody>
                                    @foreach($students as $student)
                                        <tr>
                                            <td align="center">{{ $loop->iteration }}</td>
                                            <td align="center">{{ $student->adno }}</td>
                                            <td align="center">{{ $student->rollno }}</td>
                                            <td>{{ strtoupper($student->name) }}</td>
                                            @php $presentHours=$allHours=0;  @endphp
                                            @foreach($subjects as $subject)
                                                @php 
                                                    if(isset($data[$student->student_id][$subject['id']])) {
                                                        $allHours += $subject['hours'];
                                                        $presentHours += $data[$student->student_id][$subject['id']]['present'];
                                                    }
                                                @endphp
                                                @if(isset($data[$student->student_id][$subject['id']]))
                                                    <td align="center">{{ $data[$student->student_id][$subject['id']]['present']}}</td>
                                                    <td align="center">{{ $data[$student->student_id][$subject['id']]['percent'] }}</td>
                                                @else
                                                    <td></td>
                                                    <td></td>
                                                @endif
                                            @endforeach
                                            @php 
                                            $totalPercent=0;
                                            if($allHours>0){ $totalPercent = round(($presentHours/$allHours)*100); }
                                            @endphp
                                            <td align="center">{{ $presentHours}}</td>
                                            <td align="center">{{ $totalPercent }}</td>
                                        </tr>
                                    @endforeach
                                </tbody>
                            </table>
                        </div>
                    </div>
                </div>
            </div>
        </div>
    @else
        <div class="alert alert-warning">No Result Found !</div>
    @endif
    <script src="{{ asset('public/js/student-attendance.js?ver=1.38') }}"></script>
@endsection