@extends('layouts.settings-template')
@section('title','Settings')
@section('heading','Syllabus')
@section('breadcrumb','Settings / Course / Syllabus')
@section('content')
    <div class="card card-primary">
        <div class="card-header">Add Syllabus</div>
        <div class="card-body">
            <form action="{{ route('syllabus.save') }}" method="post" enctype="multipart/form-data">
                @csrf
                <div class="row">
                    <div class="col-12 col-sm-4">
                        <div class="form-group">
                            <label for="course_id" class="required">Program</label>
                            <select class="js-example-basic-single" id="course_id" name="course_id" style="width:100%">
                                <option value="">Select</option>
                                @foreach($courses as $course)
                                    <option value="{{ $course->course_id }}" {{ old('course_id') == $course->course_id ? "selected":"" }}>{{ $course->course_name}}</option>
                                @endforeach
                            </select>
                        </div>
                    </div>
                    <div class="col-12 col-sm-4">
                        <div class="form-group">
                            <label for="semester_id" class="required">Semester</label>
                            <select class="js-example-basic-single" id="semester_id" name="semester_id" style="width:100%">
                                <option value="">Select</option>
                                @foreach($semesters as $semester)
                                    <option value="{{ $semester->semester_id  }}" {{ old('semester_id') == $semester->semester_id ? "selected":"" }}>{{ $semester->semester_name}}</option>
                                @endforeach
                            </select>
                        </div>
                    </div>
                    <div class="col-12 col-sm-4">
                        <div class="form-group">
                            <label for="subcat_id" class="required">Course Category</label>
                            <select class="js-example-basic-single" id="subcat_id" name="subcat_id" style="width:100%">
                                <option value="">Select</option>
                                @foreach($subcats as $subcat)
                                    <option value="{{ $subcat->id  }}" {{ old('subcat_id') == $subcat->id ? "selected":"" }}>{{ $subcat->category}}</option>
                                @endforeach
                            </select>
                        </div>
                    </div>
                </div>
                <div class="row">
                    <div class="col-12 col-sm-4">
                        <div class="form-group">
                            <label for="subject_id" class="required">Course</label>
                            <select class="js-example-basic-single" id="subject_id" name="subject_id" style="width:100%">
                                <option value="">Select</option>
                            </select>
                        </div>
                    </div>
                    <div class="col-12 col-sm-4">
                        <div class="form-group">
                            <label for="text">click here to type syllabus</label>
                            <input type="checkbox" class="form-control @error('text') border-danger  @enderror" id="textCheckbox" name="text" value="{{ old('text') }}" style="height:15px;width:15px">
                            <div class="row"><br>
                                <textarea name="text" id="textBox" class="form-control" style="display:none; margin-top: 10px;"></textarea>
                            </div>
                        </div>
                    </div>
                    <div class="col-12 col-sm-4">
                        <div class="form-group">
                            <label for="photo" >Syllabus</label>
                            <input type="file" class="form-control @error('photo') border-danger @enderror" id="photo" name="photo" value="{{ old('photo') }}">
                        </div>
                    </div>
                </div>
                <div class="row">
                    <div class="col-12">
                        <div class="form-group">
                            <button type="submit" class="btn btn-success float-right">Save</button>
                        </div>
                    </div>
                </div>
            </form>
        </div>
    </div>
    <br>
    <div class="card card-primary">
        <div class="card-header">View Syllabus</div>
        <div class="card-body">
            <table class="table table-bordered">
                <thead>
                <tr>
                    <th>#</th>
                    <th>Program</th>
                    <th>Semester</th>
                    <th>Course</th>
                    <th>Text</th>
                    <th>Attachment</th>
                </tr>
                </thead>
                <tbody>
                    @forelse($syllabuses as $syllabus)
                        <tr>
                            <td align="center">{{ $loop->iteration }}</td>
                            <td align="center">{{ $syllabus->course->course_name }}</td>
                            <td align="center">{{ $syllabus->semester->semester_name }}</td>
                            <td align="center">{{ $syllabus->subject->subject_name }}</td>
                            <td style="word-wrap: break-word; word-break: break-all; white-space: normal;">{{ $syllabus->text }}</td>
                            <td>
                                @if($syllabus->photo)
                                    <a href="{{ asset('public/uploads/student/syllabus/'.$syllabus->photo) }}" download>Download</a>
                                @endif
                            </td>
                        </tr>
                    @empty
                        <tr>
                            <td colspan="6">No Result Found !</td>
                        </tr>
                    @endforelse
                </tbody>
            </table>
        </div>
    </div>
    <script src="{{ asset('public/template/plugins/jquery/jquery.min.js') }}"></script>
    <script src="{{ asset('public/js/sem.js') }}"></script> 
    <script src="{{ asset('public/js/sub.js') }}"></script> 
    <script>
        $(document).ready(function () {
            $('#textCheckbox').on('change', function () {
                if ($(this).is(':checked')) {
                    $('#textBox').show();
                } else {
                    $('#textBox').hide();
                }
            });
        });
    </script> 
@endsection